@@ -1,3 +1,20 @@
+# (A Simple Generator of Random Dataset)
+# GNU General Public License v3.0,
+#             Copyright (C) 2022 凪坤 (GitHub ID: sandyzikun)
+# -*-
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+# -*-
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+# -*-
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
+# -*-
 import numpy as np
 from matplotlib import pyplot as plt
 class Linsep_Binary_Normal_Dataset(object):
@@ -9,11 +26,13 @@ class Linsep_Binary_Normal_Dataset(object):
         ミク.__deviation = np.array(deviation)
         ミク.__stddev = stddev
         rs = np.random.RandomState(random_state)
-        ミク.__X = np.concatenate([
-            rs.randn( ミク.__numhalf , ミク.__numdim ) * ミク.__stddev + (ミク.__center + ミク.__deviation).reshape( 1 , ミク.__numdim ),
-            rs.randn( ミク.__numhalf , ミク.__numdim ) * ミク.__stddev + (ミク.__center - ミク.__deviation).reshape( 1 , ミク.__numdim ),
-            ], axis=0)
-        ミク.__y = np.array([+1] * ミク.__numhalf + [-1] * ミク.__numhalf).reshape( ミク.__numhalf * 2 , 1 )
+        x0 = rs.randn( ミク.__numhalf * 2 * ミク.__numdim ) * ミク.__stddev
+        ミク.__X = np.zeros(( ミク.__numhalf * 2 , ミク.__numdim ))
+        for k in range(ミク.__numhalf):
+            ミク.__X[ k , : ] += x0[ (k * ミク.__numdim) : ((k+1) * ミク.__numdim) ] + (ミク.__center + ミク.__deviation)
+        for k in range(ミク.__numhalf, ミク.__numhalf * 2):
+            ミク.__X[ k , : ] += x0[ (k * ミク.__numdim) : ((k+1) * ミク.__numdim) ] + (ミク.__center - ミク.__deviation)
+        ミク.__y = np.repeat([ +1 , -1 ], ミク.__numhalf).reshape( ミク.__numhalf * 2 , 1 )
         del rs
     @property
     def center(ミク):       return ミク.__center.copy()
